@@ -9,7 +9,9 @@ from pycodeanalyzer.core.abstraction.objects import (
 )
 from pycodeanalyzer.core.languages.analyzers.cppanalyzer import CppAnalyzer
 from pycodeanalyzer.core.languages.analyzers.javaanalyzer import JavaAnalyzer
+from pycodeanalyzer.core.languages.analyzers.kotlinanalyzer import KotlinAnalyzer
 from pycodeanalyzer.core.languages.analyzers.pythonanalyzer import PythonAnalyzer
+from pycodeanalyzer.core.languages.extensions import languageExtensions
 from pycodeanalyzer.core.logging.loggerfactory import LoggerFactory
 from pycodeanalyzer.ui.app import UiFileDispatcherListener
 
@@ -27,12 +29,14 @@ class FileDispatcher:
         cppAnalyzer: CppAnalyzer,
         pythonAnalyzer: PythonAnalyzer,
         javaAnalyzer: JavaAnalyzer,
+        kotlinAnalyzer: KotlinAnalyzer,
         uiListener: UiFileDispatcherListener,
     ) -> None:
         self.logger = LoggerFactory.createLogger(__name__)
         self.cppAnalyzer = cppAnalyzer
         self.pythonAnalyzer = pythonAnalyzer
         self.javaAnalyzer = javaAnalyzer
+        self.kotlinAnalyzer = kotlinAnalyzer
         self.uiListener = uiListener
 
     def dispatchRoots(self, roots: List[Tuple[str, List[str]]]) -> List[AbstractObject]:
@@ -48,15 +52,21 @@ class FileDispatcher:
         abstractObjects = []
         for file in files:
             extension = pathlib.Path(file).suffix
-            if extension == ".h" or extension == ".hpp":
+            language = None
+            if extension in languageExtensions.keys():
+                language = languageExtensions[extension]
+            if language == "CPP":
                 self.uiListener.notifyAnalyzing(file)
                 abstractObjects += self.cppAnalyzer.analyze(rootDir, file)
-            if extension == ".py":
+            if language == "PYTHON":
                 self.uiListener.notifyAnalyzing(file)
                 abstractObjects += self.pythonAnalyzer.analyze(rootDir, file)
-            if extension == ".java":
+            if language == "JAVA":
                 self.uiListener.notifyAnalyzing(file)
                 abstractObjects += self.javaAnalyzer.analyze(rootDir, file)
+            if language == "KOTLIN":
+                self.uiListener.notifyAnalyzing(file)
+                abstractObjects += self.kotlinAnalyzer.analyze(rootDir, file)
         return abstractObjects
 
     def sortObjects(
