@@ -44,6 +44,7 @@ class UiStatListener(UiLink):
         nbClasses: int,
         nbEnums: int,
         nbFunctions: int,
+        languagePie: str,
         duration: float,
     ) -> None:
         if self.socketio:
@@ -54,6 +55,7 @@ class UiStatListener(UiLink):
                     "nbClasses": nbClasses,
                     "nbEnums": nbEnums,
                     "nbFunctions": nbFunctions,
+                    "languagePie": languagePie,
                     "duration": duration,
                 },
             )
@@ -101,6 +103,10 @@ class UiBrowseListener(UiLink):
         if self.socketio:
             self.socketio.emit("searchResult", {"res": searchRes})
 
+    def notifyUsedByUse(self, activated: bool) -> None:
+        if self.socketio:
+            self.socketio.emit("usedByUseChange", {"activated": activated})
+
 
 @singleton
 class Application:
@@ -123,6 +129,7 @@ class Application:
         self.app.config["SECRET_KEY"] = secrets.token_urlsafe(16)
         self.app.use_reloader = True
         self.socketio = SocketIO(self.app, logger=False, engineio_logger=False)
+        self.ui: FlaskUI = None
         uiFileDispatcherListener.setSocketIO(self.socketio)
         uiStatListener.setSocketIO(self.socketio)
         uiStatListener.setSocketIO(self.socketio)
@@ -130,11 +137,14 @@ class Application:
         FlaskHolder.register(self.app, route_base="/")
 
     def run(self) -> None:
-        threading.Thread(
-            target=lambda: FlaskUI(
-                self.app, socketio=self.socketio, start_server="flask-socketio"
-            ).run()
-        ).start()
+        self.ui = FlaskUI(
+            self.app, socketio=self.socketio, start_server="flask-socketio"
+        )
+        threading.Thread(target=lambda: self.ui.run()).start()
+
+    def quit(self) -> None:
+        if self.ui:
+            self.ui.idle_interval = 0
 
 
 class FlaskHolder(FlaskView):
