@@ -6,6 +6,14 @@ let classTree;
 const itemNamespacePath = [];
 let currentItemKey = '__classes__';
 
+function hideVisibility(element) {
+	element.style.display = 'none';
+}
+
+function showVisibility(element) {
+	element.style.display = 'block';
+}
+
 function updateClassList(treeRoot, isAbsoluteRoot) {
 	currentItemKey = '__classes__';
 	updateItemList(treeRoot, isAbsoluteRoot, currentItemKey);
@@ -104,6 +112,9 @@ function updateClassView(klass, diag) {
 	const itemName = document.getElementById('ItemName');
 	const itemDiag = document.getElementById('ItemDiag');
 	const itemDesc = document.getElementById('ItemDesc');
+	const itemUsedBy = document.getElementById('ItemUsedBy');
+	const loaderDiv = document.getElementById('LoaderDiv');
+	const contentDiv = document.getElementById('ContentDiv');
 
 	itemName.innerHTML = klass.name;
 	console.log(diag);
@@ -137,6 +148,23 @@ function updateClassView(klass, diag) {
 		itemDiag.innerHTML = code;
 	};
 
+	let usedByList = '<h3>Used by</h3>';
+	usedByList += '<h4>Classes</h4><ul class="inherits-link">';
+	if (Object.keys(klass.usedBy).length === 0) {
+		usedByList += '<li class="inherits-link">Not activated</li>';
+	} else if (klass.usedBy.Classes.length > 0) {
+		for (const userItem of klass.usedBy.Classes) {
+			usedByList += '<li class="inherits-link"><a href="#" onclick="requestClassData(\'' + userItem + '\');return false;">' + userItem + '</a></li>';
+		}
+	} else {
+		usedByList += '<li class="inherits-link">None</li>';
+	}
+
+	usedByList += '</ul>';
+	itemUsedBy.innerHTML = usedByList;
+
+	hideVisibility(loaderDiv);
+	showVisibility(contentDiv);
 	mermaid.render('preparedScheme', diag, insert);
 	const svg = document.getElementById('preparedScheme');
 	const links = svg.getElementsByTagName('a');
@@ -152,6 +180,9 @@ function updateEnumView(enumData, diag) {
 	const itemName = document.getElementById('ItemName');
 	const itemDiag = document.getElementById('ItemDiag');
 	const itemDesc = document.getElementById('ItemDesc');
+	const itemUsedBy = document.getElementById('ItemUsedBy');
+	const loaderDiv = document.getElementById('LoaderDiv');
+	const contentDiv = document.getElementById('ContentDiv');
 
 	itemName.innerHTML = enumData.name;
 	console.log(diag);
@@ -171,6 +202,23 @@ function updateEnumView(enumData, diag) {
 		itemDiag.innerHTML = code;
 	};
 
+	let usedByList = '<h3>Used by</h3>';
+	usedByList += '<h4>Classes</h4><ul class="inherits-link">';
+	if (Object.keys(enumData.usedBy).length === 0) {
+		usedByList += '<li class="inherits-link">Not activated</li>';
+	} else if (enumData.usedBy.Classes.length > 0) {
+		for (const userItem of enumData.usedBy.Classes) {
+			usedByList += '<li class="inherits-link"><a href="#" onclick="requestClassData(\'' + userItem + '\');return false;">' + userItem + '</a></li>';
+		}
+	} else {
+		usedByList += '<li class="inherits-link">None</li>';
+	}
+
+	usedByList += '</ul>';
+	itemUsedBy.innerHTML = usedByList;
+
+	hideVisibility(loaderDiv);
+	showVisibility(contentDiv);
 	mermaid.render('preparedScheme', diag, insert);
 }
 
@@ -178,7 +226,11 @@ function updateFunctionView(functionData) {
 	const itemName = document.getElementById('ItemName');
 	const itemDiag = document.getElementById('ItemDiag');
 	const itemDesc = document.getElementById('ItemDesc');
+	const loaderDiv = document.getElementById('LoaderDiv');
+	const contentDiv = document.getElementById('ContentDiv');
+	const itemUsedBy = document.getElementById('ItemUsedBy');
 
+	itemUsedBy.innerHTML = '';
 	itemName.innerHTML = functionData.name;
 	itemDiag.innerHTML = '';
 	// eslint-disable-next-line prefer-destructuring
@@ -189,7 +241,7 @@ function updateFunctionView(functionData) {
 
 	let defLine = functionData.rtype + ' ' + functionData.name + '(';
 
-	if (functionData.params.length > 0) {
+	if (Object.keys(functionData.params).length > 0) {
 		for (const key of Object.keys(functionData.params).values()) {
 			defLine += functionData.params[key] + ' ' + key + ', ';
 		}
@@ -205,6 +257,8 @@ function updateFunctionView(functionData) {
            + '<h2>Definition</h2>'
            + '<div class="left"><pre><code>' + defLine + '</code></pre></div>';
 	itemDesc.innerHTML = desc;
+	hideVisibility(loaderDiv);
+	showVisibility(contentDiv);
 	hljs.highlightAll();
 }
 
@@ -212,8 +266,14 @@ function updateFileView(fileData) {
 	const itemName = document.getElementById('ItemName');
 	const itemDiag = document.getElementById('ItemDiag');
 	const itemDesc = document.getElementById('ItemDesc');
-	const {path} = fileData;
+	const loaderDiv = document.getElementById('LoaderDiv');
+	const contentDiv = document.getElementById('ContentDiv');
+	const itemUsedBy = document.getElementById('ItemUsedBy');
 
+	// eslint-disable-next-line prefer-destructuring
+	const path = fileData.path;
+
+	itemUsedBy.innerHTML = '';
 	itemName.innerHTML = fileData.name;
 	itemDiag.innerHTML = '';
 
@@ -252,10 +312,16 @@ function updateFileView(fileData) {
            + '<h2>Content</h2><br>'
            + '<div class="left"><pre><code>' + fileData.content + '</code></pre></div>';
 	itemDesc.innerHTML = desc;
+	hideVisibility(loaderDiv);
+	showVisibility(contentDiv);
 	hljs.highlightAll();
 }
 
 function requestClassData(klass) {
+	const loaderDiv = document.getElementById('LoaderDiv');
+	const contentDiv = document.getElementById('ContentDiv');
+	hideVisibility(contentDiv);
+	showVisibility(loaderDiv);
 	console.log('requestClassData : ' + klass);
 	socket.emit('fetchClassData', {
 		data: 'request fetchClassData',
@@ -264,6 +330,10 @@ function requestClassData(klass) {
 }
 
 function requestEnumData(enumData) {
+	const loaderDiv = document.getElementById('LoaderDiv');
+	const contentDiv = document.getElementById('ContentDiv');
+	hideVisibility(contentDiv);
+	showVisibility(loaderDiv);
 	console.log('requestEnumData : ' + enumData);
 	socket.emit('fetchEnumData', {
 		data: 'request fetchEnumData',
@@ -273,6 +343,10 @@ function requestEnumData(enumData) {
 
 // eslint-disable-next-line no-unused-vars
 function requestFunctionData(functionData) {
+	const loaderDiv = document.getElementById('LoaderDiv');
+	const contentDiv = document.getElementById('ContentDiv');
+	hideVisibility(contentDiv);
+	showVisibility(loaderDiv);
 	console.log('requestFunctionData : ' + functionData);
 	socket.emit('fetchFunctionData', {
 		data: 'request fetchFunctionData',
@@ -282,6 +356,10 @@ function requestFunctionData(functionData) {
 
 // eslint-disable-next-line no-unused-vars
 function requestFileData(fileData) {
+	const loaderDiv = document.getElementById('LoaderDiv');
+	const contentDiv = document.getElementById('ContentDiv');
+	hideVisibility(contentDiv);
+	showVisibility(loaderDiv);
 	console.log('requestFileData : ' + fileData);
 	socket.emit('fetchFileData', {
 		data: 'request fetchFileData',
@@ -301,6 +379,10 @@ function setupSearch() {
 
 // eslint-disable-next-line no-unused-vars
 function performSearch() {
+	const loaderDiv = document.getElementById('LoaderDiv');
+	const contentDiv = document.getElementById('ContentDiv');
+	hideVisibility(contentDiv);
+	showVisibility(loaderDiv);
 	const itemSearch = document.getElementById('code-search-text');
 	const token = itemSearch.value;
 	socket.emit('searchData', {
@@ -310,7 +392,14 @@ function performSearch() {
 }
 
 function showSearchResult(res) {
+	const loaderDiv = document.getElementById('LoaderDiv');
+	const contentDiv = document.getElementById('ContentDiv');
+	const itemUsedBy = document.getElementById('ItemUsedBy');
 	const itemDiag = document.getElementById('ItemDiag');
+
+	hideVisibility(loaderDiv);
+	showVisibility(contentDiv);
+	itemUsedBy.innerHTML = '';
 	let presentation = 'Found ' + res.length + ' results.<h2>Results :</h2><div class="left">';
 	for (const item of res) {
 		const path = item[0];
@@ -323,9 +412,20 @@ function showSearchResult(res) {
 	hljs.highlightAll();
 }
 
+// eslint-disable-next-line no-unused-vars
+function toggleUsedBy() {
+	const checkBox = document.getElementById('usedByCB');
+	socket.emit('changeUsedByUse', {
+		activated: checkBox.checked,
+	});
+}
+
 socket.on('connect', () => {
 	const pathItems = window.location.pathname.split('/');
 	const key = pathItems[pathItems.length - 1];
+	socket.emit('requestUsedByUse', {
+		data: 'request usedBy activation',
+	});
 	console.log('fetch  : ' + key);
 	if (key === 'classes') {
 		currentItemKey = '__classes__';
@@ -411,6 +511,12 @@ socket.on('searchResult', msg => {
 	showSearchResult(res);
 });
 
+socket.on('usedByUseChange', msg => {
+	console.log('usedByUseChange received');
+	const checkBox = document.getElementById('usedByCB');
+	checkBox.checked = msg.activated;
+});
+
 // eslint-disable-next-line no-unused-vars
 function onNodeClick(text) {
 	const items = text.split('££');
