@@ -1,4 +1,4 @@
-/* global io */
+/* global io, mermaid */
 
 const socket = io.connect('http://' + document.domain + ':' + location.port);
 
@@ -15,9 +15,25 @@ socket.on('statsChange', msg => {
 	const spanEnums = document.getElementById('nbEnums');
 	const spanFunctions = document.getElementById('nbFunctions');
 	const spanDuration = document.getElementById('duration');
+	const languagePieDiag = document.getElementById('LanguagePieDiag');
 	spanFiles.innerHTML = msg.nbFiles;
 	spanClasses.innerHTML = msg.nbClasses;
 	spanEnums.innerHTML = msg.nbEnums;
 	spanFunctions.innerHTML = msg.nbFunctions;
 	spanDuration.innerHTML = msg.duration;
+	languagePieDiag.innerHTML = msg.languagePie;
+	console.log(msg.languagePie);
+
+	languagePieDiag.removeAttribute('data-processed');
+	const insert = function (code) {
+		languagePieDiag.innerHTML = code;
+	};
+
+	mermaid.render('preparedScheme', msg.languagePie, insert);
 });
+
+const config = {
+	startOnLoad: true,
+	securityLevel: 'loose',
+};
+mermaid.initialize(config);
